@@ -7,7 +7,7 @@ use CLASS;
 BEGIN {
 	use Exporter ();
 	use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-	$VERSION     = 0.2;
+	$VERSION     = 0.3;
 	@ISA         = qw (Exporter);
 	#Give a hoot don't pollute, do not export more than needed by default
 	@EXPORT      = qw ();
@@ -95,7 +95,7 @@ See Also   : Net::IP::Route::Reject->del
 ################################################## subroutine header end ##
 sub add {
     my ($self,$ip)=@_;
-    CLASS->_reject('add',$ip);
+    CLASS->_reject('add',$ip) ;
 }
 ################################################ subroutine header begin ##
 
@@ -136,14 +136,16 @@ See Also   : IPC::Cmd:
 
 ################################################## subroutine header end ##
 sub _reject {
-    my ($self,%parameters) = @_;
-    @ipaddr = grep $ipv4regex, $message; #strip out anything that doesn't belong in an ip addres
-    $_routecmd[1]='add';
-    $_routecmd[2]=$ipaddr;
+    my ($self,$operation, $ip) = @_;
+    carp ("no ip address supplied") unless defined $ip;
+    my @ipaddr = grep $ipv4regex, $ip; #strip out anything that doesn't belong in an ip addres
+    carp ("unsupported operation") unless ($operation eq 'add' ) or ($operation eq 'del');
+    $_routecmd[1]=$operation;
+    $_routecmd[2]=$ipaddr[0];
     
-    unless (run(command => \@routecmd, verbose =>0))
+    unless (run(command => \@_routecmd, verbose =>0))
     {
-	my $errmesg = (scalar localtime)." failed to add reject route for $ipaddr (maybe its already listed?)\n ";
+	my $errmesg = (scalar localtime)." failed to add reject route for $ip (maybe its already listed?)\n ";
 	carp $errmesg;
     }
 }
